#!/bin/sh
# This is executed on the host and target machine.
# Must be root to run this -- execute it with fakeroot on host machine.
# If you follow this template and never delete anything from this file
# (just keep on adding), you'll be able to upgrade any past version
# to the current version.
#

#
# local vars defined
#

# Set this to yes of you want to enable NAS app caching.
enable_app_caching=no
do_sync=/bin/sync

# I need random support in the shell for RANDOM.
tmp_outf=/tmp/outf.${RANDOM}
echo "File for tmp operations will be [$tmp_outf]... "

if [ "$1" = "host" ] ; then

    . ./build.env
    src_root=${BUILD_DIR}/${LINUXRTCONFIG_IMG_NAME}
    dest_root=${CONF_UPDATE_BUILD_DIR}
    fd_root=${EROOT_DIR}/factorydefaults
    vers_path=${EROOT_DIR}/etcrc

    echo "Creating rw update image... "

    # make the required directories
    rm -rRf ${dest_root}
    mkdir -p ${dest_root}

    # this script should be availabe on target
    cp -f confupdate.sh ${dest_root}/.
    chown root.root ${dest_root}/confupdate.sh
    chmod 755 ${dest_root}/confupdate.sh

    echo "src_root on host is [$src_root] "
    echo "dest_root on host is [$dest_root] "

elif [ "$1" = "target" ] ; then

    . /usr/local/sbin/getpinfo-functions

    src_root=/linuxrwfs/update.d/confupdate
    dest_root=/linuxrwfs
    fd_root=/factorydefaults
    vers_path=/etcrc

    echo "Finishing up firmware upgrade... "

    # Should I check version here and switch on it if user skipped
    # some upgrades?

    echo "dest_root on target is [$dest_root] "

else

    echo "Can't execute $0 "
    exit 1

fi

# returns 0 if found, non-zero otherwise.
handle_disable()
{

  sl=$1
  path=${dest_root}/etc/init.d/.disable
  ret=0
  if [ "x`/bin/ls ${path} | grep -w \"S[0-9][0-9]$sl\"`" = "x" ] ; then
    ret=1
  fi

  return $ret
}

# gets the param from the list pointed to by index
# index starts from 1. To get the parameter as a string:
# var=`get_parm "$list" "3"`
get_parm()
{
  list=$1
  index=$2
  val=`/bin/echo $list | awk '{ print $'$index' }'`
  echo $val
}

############## This is where you have to put your files #############

platform=`cat ${vers_path}/versverb | grep "platform:" | awk '{ print $2 }'`

#
# Make required directory structure
#
[ -d ${dest_root}/etc ] || \
  mkdir -p ${dest_root}/etc

# for startup scripts
[ -d ${dest_root}/etc/init.d ] || \
  mkdir -p ${dest_root}/etc/init.d

# disabled stuff
[ -d ${dest_root}/etc/init.d/.disable ] || \
  mkdir -p ${dest_root}/etc/init.d/.disable

# apache needs this
[ -d ${dest_root}/etc/httpd/conf ] || \
  mkdir -p ${dest_root}/etc/httpd/conf

# some network config
[ -d ${dest_root}/etc/network ] || \
  mkdir -p ${dest_root}/etc/network

[ -d ${dest_root}/etc/sysconfig/network-scripts ] || \
  mkdir -p ${dest_root}/etc/sysconfig/network-scripts

[ -d ${dest_root}/etc/sysconfig/network-scripts/udhcpc ] || \
  mkdir -p ${dest_root}/etc/sysconfig/network-scripts/udhcpc

# nas config stuff
[ -d ${dest_root}/etc/nas ] || \
  mkdir -p ${dest_root}/etc/nas

# sata naming
[ -d ${dest_root}/etc/udev ] || \
  mkdir -p ${dest_root}/etc/udev

# ifplugd config
[ -d ${dest_root}/etc/ifplugd ] || \
  mkdir -p ${dest_root}/etc/ifplugd

# cron.d config
[ -d ${dest_root}/etc/cron.d ] || \
  mkdir -p ${dest_root}/etc/cron.d

# usb udev rules
[ -d ${dest_root}/etc/dev.d/block ] || \
  mkdir -p ${dest_root}/etc/dev.d/block

[ -d ${dest_root}/etc/dev.d/usb ] || \
  mkdir -p ${dest_root}/etc/dev.d/usb

# lvm configuration
[ -d ${dest_root}/etc/lvm ] || \
  mkdir -p ${dest_root}/etc/lvm

# udev rules
[ -d ${dest_root}/etc/udev/rules.d ] || \
  mkdir -p ${dest_root}/etc/udev/rules.d

# mibs dir
[ -d ${dest_root}/usr/share/snmp/mibs ] || \
  mkdir -p ${dest_root}/usr/share/snmp/mibs

# samba config dir
[ -d ${dest_root}/etc/samba ] || \
  mkdir -p ${dest_root}/etc/samba

# PAM stuff
[ -d ${dest_root}/etc/default ] || \
  mkdir -p ${dest_root}/etc/default

[ -d ${dest_root}/etc/pam.d ] || \
  mkdir -p ${dest_root}/etc/pam.d

# ntpd.d
[ -d ${dest_root}/etc/ntpd.d ] || \
  mkdir -p ${dest_root}/etc/ntpd.d

# logrotate.d 
[ -d ${dest_root}/etc/logrotate.d ] || \
  mkdir -p ${dest_root}/etc/logrotate.d

#
# /etc/ directory
#

fname=profile
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

fname=issue
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 444 ${dest_root}/etc/$fname

fname=shells
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

fname=nsswitch.conf
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

fname=ftpusers
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

fname=and.priorities
cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

# remove create line from mdadm.conf
fname=mdadm.conf
if [ -f ${dest_root}/etc/$fname ] ; then
  cat ${dest_root}/etc/$fname |grep -v "CREATE" >${tmp_outf}
  mv ${tmp_outf} ${dest_root}/etc/$fname
  chown root.root ${dest_root}/etc/$fname
  chmod 644 ${dest_root}/etc/$fname
fi

# update vsftpd.conf
fname=vsftpd.conf
if [ -f ${dest_root}/etc/${fname} ] ; then
  if [ "x`cat ${dest_root}/etc/${fname} | grep use_localtime`" = "x" ] ; then
    echo "use_localtime=YES" >>${dest_root}/etc/${fname}
  fi
else
  cp -af ${src_root}/etc/$fname ${dest_root}/etc/$fname
fi

chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

# change the home dir of the apache and admin user in the password file

# get the original list without the ones mentioned above
list="apache: \
      admin: \
      +:::::"
fname_list="passwd \
            passwd-"
for fname in $fname_list ; do

  if [ -f ${dest_root}/etc/$fname ] ; then

    gexpr=""
    for i in $list ; do
      if [ "x$gexpr" = "x" ] ; then
        gexpr=$i
      else
        gexpr="$gexpr|$i"
      fi
    done
    cat ${dest_root}/etc/${fname} | grep -Ev "$gexpr" >${tmp_outf}

    # stuff the new info into the file. The '+' line must be the
    # last in the file.
    echo "apache:x:48:48:Linux User,,,:/var/empty:/bin/false" >>${tmp_outf}
    echo "admin:x:49:49:admin:/var/empty:/bin/false" >>${tmp_outf}
    echo "+:::::/usr/share/empty:/bin/sh" >>${tmp_outf}

    mv ${tmp_outf} ${dest_root}/etc/${fname}
    chown root.root ${dest_root}/etc/${fname}
    if [ "$fname" = "passwd" ] ; then
      chmod 644 ${dest_root}/etc/${fname}
    elif [ "$fname" = "passwd-" ] ; then
      chmod 600 ${dest_root}/etc/${fname}
    fi

  fi

done

$do_sync

# Update global.conf
# We will use really nice trick: we will get from original global.conf
# only the config that user can change. The rest of it, we'll get
# from the default file. Since factory defaults are platform
# specific, we don't have to care about the platform switching here.
# And the only thing that we are going to ever change is the usr_list.
# Keep it in the following format (and you'll end up happy):
#
# usr_list="var1 \
#           var2 \
#           var3"
#
if [ "x$platform" = "xpm74100" ] ; then
  fname_list="global-NSS6000.conf \
              global-NSS4000V2.conf"
else
  fname_list="global.conf"
fi

for fname in $fname_list ; do

  # list of the vars which can be changed by the user (keep on adding
  # if you need more)
  usr_list="FTP_MAX_CONN_SINGLE_IP"

  if [ ! -f ${dest_root}/etc/$fname ] ; then
      cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
  else
      # build grep expression to strip out values which can be
      # changed by the user.
      gexpr=""
      for i in ${usr_list} ; do
        if [ "x$gexpr" = "x" ] ; then
          gexpr=$i
        else
          gexpr="$gexpr|$i"
        fi
      done
      # output will contain everything except user configurable stuff
      /bin/tar -xzOf ${fd_root}/factorydefaults.tar.gz etc/$fname | \
                     /bin/grep -Ev "$gexpr" >${tmp_outf}

      # get user configrable stuff only from the file on the system
      /bin/cat ${dest_root}/etc/${fname} | \
               /bin/grep -E "$gexpr" >>${tmp_outf}

      cp -af ${tmp_outf} ${dest_root}/etc/$fname
      rm -f ${tmp_outf}
  fi
done

$do_sync

# juggle ntpd.conf
fname=ntpd.conf
if [ ! -f ${dest_root}/etc/$fname ] ; then
  cp -af ${src_root}/etc/$fname ${dest_root}/etc/.
else
  sed -e "s/^server /servers /g" <${dest_root}/etc/$fname >${tmp_outf}
  cat ${tmp_outf} >${dest_root}/etc/$fname
  rm -f ${tmp_outf}
fi

chown root.root ${dest_root}/etc/$fname
chmod 644 ${dest_root}/etc/$fname

$do_sync

#
# /etc/dev.d/block
#

fname=aoe_hotplug.dev
cp -af ${src_root}/etc/dev.d/block/$fname ${dest_root}/etc/dev.d/block/.
chown root.root ${dest_root}/etc/dev.d/block/$fname
chmod 755 ${dest_root}/etc/dev.d/block/$fname

fname=usb_hotplug.dev
cp -af ${src_root}/etc/dev.d/block/$fname ${dest_root}/etc/dev.d/block/.
chown root.root ${dest_root}/etc/dev.d/block/$fname
chmod 755 ${dest_root}/etc/dev.d/block/$fname

fname=sata_hotplug.dev
cp -af ${src_root}/etc/dev.d/block/$fname ${dest_root}/etc/dev.d/block/.
chown root.root ${dest_root}/etc/dev.d/block/$fname
chmod 755 ${dest_root}/etc/dev.d/block/$fname

$do_sync

#
# /etc/init.d directory
#

# do all 'S' stratup scripts here
# we don't care if they are modified because they should not be.
# This will also help in case of some kind of corruption.

# this is the list of all the 'S' services
slist="sysinit \
       checkroot \
       hwdep \
       modules \
       raid \
       lvm \
       mount \
       mtd \
       tmpfs \
       sensors \
       urandom \
       fixrandom \
       safenet \
       certs \
       iptables \
       network \
       aggregation \
       ntpd \
       portmap \
       dropbear \
       ups \
       nfs \
       vsftpd \
       httpdswiw \
       httpdsl1 \
       httpds \
       httpd \
       ypbind \
       upnpd \
       cupsd \
       samba \
       winbind \
       crond \
       and \
       dagent \
       mdnsresponderd \
       local"

# this is the list of the corresponding startup numbers for the services
# above
nslist="01 \
        02 \
        02 \
        03 \
        04 \
        05 \
        06 \
        07 \
        08 \
        09 \
        20 \
        21 \
        25 \
        30 \
        31 \
        40 \
        41 \
        42 \
        45 \
        50 \
        51 \
        52 \
        60 \
        82 \
        83 \
        84 \
        85 \
        86 \
        87 \
        89 \
        90 \
        91 \
        93 \
        94 \
        97 \
        98 \
        99"

cnt=1
for i in $slist ; do
  fname_s=${i}
  fname=_${fname_s}
  snum=`/bin/echo ${nslist} | /usr/bin/awk '{ print $'$cnt' }'`
  fname_sl=S${snum}${fname_s}
  rm -f ${dest_root}/etc/init.d/S*${fname_s}
  cp -af ${src_root}/etc/init.d/$fname ${dest_root}/etc/init.d/.
  ( cd ${dest_root}/etc/init.d ; \
    ln -s $fname ${fname_sl} ; \
    handle_disable "$fname_s" ; \
    if [ $? -eq 0 ] ; then
      rm -f .disable/S*${fname_s}
      mv S*${fname_s} .disable/.
    fi ; \
  )
  chown root.root ${dest_root}/etc/init.d/$fname
  chmod 755 ${dest_root}/etc/init.d/$fname
  cnt=`/usr/bin/expr $cnt + 1`
done
$do_sync

# do all non-'S' startup scripts here (these are helper scripts).
hslist="_bootok \
        _dmesglog \
        _getExports.pl \
        _getRandPort.pl \
        _hwcrypto \
        _ifplugd \
        _mkUPNPcfg \
        _nfsd \
        _nfslock \
        _raidReport \
        _sethostname \
        _setmDNSconfig \
        _vblade"

for i in $hslist ; do
  fname=${i}
  cp -af ${src_root}/etc/init.d/$fname ${dest_root}/etc/init.d/.
  chown root.root ${dest_root}/etc/init.d/$fname
  chmod 755 ${dest_root}/etc/init.d/$fname
done

$do_sync

#
# /etc/httpd/conf
#
fname=httpd.conf
cp -af ${src_root}/etc/httpd/conf/${fname} ${dest_root}/etc/httpd/conf/.
chown root.root ${dest_root}/etc/httpd/conf/${fname}
chmod 644 ${dest_root}/etc/httpd/conf/${fname}

fname=httpd.conf.l1
cp -af ${src_root}/etc/httpd/conf/${fname} ${dest_root}/etc/httpd/conf/.
chown root.root ${dest_root}/etc/httpd/conf/${fname}
chmod 644 ${dest_root}/etc/httpd/conf/${fname}

fname=httpd.conf.wiw
cp -af ${src_root}/etc/httpd/conf/${fname} ${dest_root}/etc/httpd/conf/.
chown root.root ${dest_root}/etc/httpd/conf/${fname}
chmod 644 ${dest_root}/etc/httpd/conf/${fname}

fname=nasdav.conf
cp -af ${src_root}/etc/httpd/conf/${fname} ${dest_root}/etc/httpd/conf/.
chown root.root ${dest_root}/etc/httpd/conf/${fname}
chmod 644 ${dest_root}/etc/httpd/conf/${fname}

$do_sync

#
# /etc/pam.d directory
#

# vsftpd
fname=vsftpd
cp -af ${src_root}/etc/pam.d/$fname ${dest_root}/etc/pam.d/.
chown root.root ${dest_root}/etc/pam.d/$fname
chmod 644 ${dest_root}/etc/pam.d/$fname

#
# /etc/logrotate.d directory
#

# systemlog
fname=systemlog
cp -af ${src_root}/etc/logrotate.d/$fname ${dest_root}/etc/logrotate.d/.
chown root.root ${dest_root}/etc/logrotate.d/$fname
chmod 644 ${dest_root}/etc/logrotate.d/$fname

# dmesglog
fname=dmesglog
cp -af ${src_root}/etc/logrotate.d/$fname ${dest_root}/etc/logrotate.d/.
chown root.root ${dest_root}/etc/logrotate.d/$fname
chmod 644 ${dest_root}/etc/logrotate.d/$fname

$do_sync

#
# /etc/samba
#

# Update smb.conf
fname=smb.conf
if [ ! -f ${dest_root}/etc/samba/$fname ] ; then
    cp -af ${src_root}/etc/samba/$fname ${dest_root}/etc/samba/.
else
    # make sure that we do have 'netbios name =' string in the file
    cp -af ${dest_root}/etc/samba/$fname ${tmp_outf}
    var=`grep -e "\( *\)netbios name\( *\)=\(.*\)" ${tmp_outf} | grep -v "#"`
    if [ "x${var}" = "x" ] ; then
      # hook myself up to global section
      str="\[global\]"
      strnew="[global]\n\nnetbios name =\n"
      sed -i ${tmp_outf} -e "/^${str}/s,${str},${strnew},"
    fi

    cp -af ${tmp_outf} ${dest_root}/etc/samba/$fname
    rm -f ${tmp_outf}
fi

$do_sync

#
# /usr/share/snmp/mibs
#
fname=MicroNAS-MIB.txt
if [ -f ${dest_root}/usr/share/snmp/mibs/${fname} ] ; then
  rm -f ${dest_root}/usr/share/snmp/mibs/${fname}
fi

fname=NSS-MIB.txt
cp -af ${src_root}/usr/share/snmp/mibs/$fname \
       ${dest_root}/usr/share/snmp/mibs/.
chown root.root ${dest_root}/usr/share/snmp/mibs/$fname
chmod 644 ${dest_root}/usr/share/snmp/mibs/$fname

$do_sync

#
# /etc/sysconfig
#

# Update network
fname=network
if [ ! -f ${dest_root}/etc/sysconfig/$fname ] ; then
    cp -af ${src_root}/etc/sysconfig/$fname ${dest_root}/etc/sysconfig/.
else
    append=`grep -w ^PULL_DNS ${dest_root}/etc/sysconfig/$fname`
    if [ "x${append}" = "x" ] ; then 
	# "PULL_DNS=bond0" entry does not exist so append it
	cp -af ${dest_root}/etc/sysconfig/$fname ${tmp_outf}
	echo "PULL_DNS=bond0" >> ${tmp_outf}
	cp -af ${tmp_outf} ${dest_root}/etc/sysconfig/$fname
	rm -f ${tmp_outf}
	$do_sync
    fi

    # Update PULL_WINS=yes
    cp -af ${dest_root}/etc/sysconfig/$fname ${tmp_outf}
    sed -i ${tmp_outf} -e "s/^PULL_WINS=\(.*\)/PULL_WINS=yes/g"
    cp -af ${tmp_outf} ${dest_root}/etc/sysconfig/$fname
    rm -f ${tmp_outf}
fi

# make sure that iptables is correct
fname=iptables
strfind="-A INPUT -i lo -j ACCEPT"
if [ -f ${dest_root}/etc/sysconfig/$fname ] ; then
  if [ "x`cat ${dest_root}/etc/sysconfig/$fname | \
        grep -e \"$strfind\"`" = "x" ] ; then
      str=":RejectCIFS - \[0:0\]"
      strnew=":RejectCIFS - \[0:0\]\n${strfind}"
      sed -e "/^${str}/s,${str},${strnew}," \
      <${dest_root}/etc/sysconfig/$fname >$tmp_outf
      cat $tmp_outf >${dest_root}/etc/sysconfig/$fname

      unset str strnew
  fi
else
  cp -af ${src_root}/etc/sysconfig/$fname ${dest_root}/etc/sysconfig/$fname
fi
chown root.root ${dest_root}/etc/sysconfig/$fname
chmod 600 ${dest_root}/etc/sysconfig/$fname
unset strfind
rm -f $tmp_outf

$do_sync

#
# /etc/nas
#
apache_gid=`/usr/bin/id -gr apache`
apache_uid=`/usr/bin/id -ur apache`

fname=config_files
cp -af ${src_root}/etc/nas/$fname \
       ${dest_root}/etc/nas/.

fname=nas.conf
if [ -f ${dest_root}/etc/nas/$fname ] ; then
  str=`cat ${dest_root}/etc/nas/$fname | grep "^\[raids\]"`
  if [ "x$str" = "x" ] ; then
    echo "'[raids]' section in $fname is missing -- adding... "
    echo "[raids]" >>${dest_root}/etc/nas/$fname
  fi
else
  cp -af ${src_root}/etc/nas/$fname \
         ${dest_root}/etc/nas/.
fi

# Set the generic ownership of /etc/nas directory
chmod 770 ${dest_root}/etc/nas
chown root.${apache_gid} ${dest_root}/etc/nas
chmod 660 ${dest_root}/etc/nas/*
chown root.${apache_gid} ${dest_root}/etc/nas/*

# create the cache file
fname=do_caching
if [ "x$enable_app_caching" = "xyes" ] ; then
  echo "Enabling NAS app caching... "
  if [ ! -f ${dest_root}/etc/nas/$fname ] ; then
    touch ${dest_root}/etc/nas/$fname
    chown root.${apache_gid} ${dest_root}/etc/nas/$fname
    chmod 660 ${dest_root}/etc/nas/$fname
   fi
else
    echo "Disabling NAS app caching... "
    rm -f ${dest_root}/etc/nas/$fname
fi

# set the individual file ownership/privs in the /etc/nas directory

# make sure that bonjour file is always owned by apache.apache
# and it has coorrect privs.
bfile=${dest_root}/etc/nas/bonjour
if [ -f ${bfile} ] ; then
  # we should avoid writing to the flash if we don't need to
  buser_correct=${apache_uid}
  bgrp_correct=${apache_gid}
  buser_real=`/bin/ls -al ${bfile} |/usr/bin/awk '{ print $3 }'`
  bgrp_real=`/bin/ls -al ${bfile} |/usr/bin/awk '{ print $4 }'`
  if [ "x${buser_real}" != "x${buser_correct}" -o \
       "x${bgrp_real}" != "x${bgrp_correct}" ] ; then
    echo "Warning: ${bfile} is owned by ${buser_real}.${bgrp_real} . "
    echo -n "Correcting ${bfile} privs and ownership... "
    /bin/chown ${buser_correct}.${bgrp_correct} ${bfile}
    /bin/chmod 600 ${bfile}
    echo "done. "
  fi
  unset buser_correct bgrp_correct buser_real bgrp_real
fi
unset bfile

$do_sync

#
# /etc/sysconfig/network-scripts
#

fname=add_servers.cmd
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname

fname=remove_servers.cmd
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname

fname=bondinit
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname

fname=ifdown
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname


fname=ifup
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname

fname=network-functions
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname

fname=network-static-defines
cp -af ${src_root}/etc/sysconfig/network-scripts/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/$fname


$do_sync

#
# /etc/sysconfig/network-scripts/udhcpc
#

fname=default.script
cp -af ${src_root}/etc/sysconfig/network-scripts/udhcpc/$fname \
       ${dest_root}/etc/sysconfig/network-scripts/udhcpc/.
chown root.root ${dest_root}/etc/sysconfig/network-scripts/udhcpc/$fname
chmod 755 ${dest_root}/etc/sysconfig/network-scripts/udhcpc/$fname

$do_sync

#
# put platform specific stuff here
#
case $platform in
    pm74100 )
        echo "Copying gpio.conf for $platform... "
        cp -af ${src_root}/etc/gpio.conf ${dest_root}/etc/.
        chown root.root ${dest_root}/etc/gpio.conf

	echo "Copying ntpd-misc.conf for $platform..."
	fname=ntpd-misc.conf
	cp -af ${src_root}/etc/ntpd.d/$fname ${dest_root}/etc/ntpd.d/.
	chown root.root ${dest_root}/etc/ntpd.d/$fname
	chmod 644 ${dest_root}/etc/ntpd.d/$fname
    ;;
    pm74101 )
        echo "Using proto A and proto B gpio.conf for $platform... "
        cp -af ${src_root}/etc/gpio.conf.proto_a ${dest_root}/etc/.
        cp -af ${src_root}/etc/gpio.conf.proto_b ${dest_root}/etc/.
        rm -f ${dest_root}/etc/gpio.conf
        chown root.root ${dest_root}/etc/gpio.conf.proto_a
        chown root.root ${dest_root}/etc/gpio.conf.proto_b

	echo "Using ntpd-misc.conf for $platform..."
	fname=ntpd-misc.conf
	cp -af ${src_root}/etc/ntpd.d/$fname ${dest_root}/etc/ntpd.d/.
	chown root.root ${dest_root}/etc/ntpd.d/$fname
	chmod 644 ${dest_root}/etc/ntpd.d/$fname
    ;;
    * )
        echo "Using gpio.conf only. $platform has only one hardware revision... "
        cp -af ${src_root}/etc/gpio.conf ${dest_root}/etc/.
        chown root.root ${dest_root}/etc/gpio.conf
esac

$do_sync

######### target specific stuff #########

if [ "$1" = "host" ] ; then

    # have to do some taring here
    ( cd ${dest_root} ; \
      tar -cpzf ${KERNELBIN_DEST}/${CONF_UPDATE_IMG_NAME} * )

elif [ "$1" = "target" ] ; then

    # this is left to us by first part of upgrade process
    cp -af ${src_root}/etc/fwupgrade-tstamp.last ${dest_root}/etc/.
    chown root.root ${dest_root}/etc/fwupgrade-tstamp.last
    chmod 644 ${dest_root}/etc/fwupgrade-tstamp.last

fi

$do_sync

exit 0
